@@ -55,6 +55,14 @@ class SoftwareKG:
         node = self.graph.find_nodes_by_property("concept_name", word)
         return node[0]['labels']
 
+    def get_all_concept(self):
+        concepts = []
+        for node_id in self.graph.get_node_ids():
+            node = self.graph.get_node_info_dict(node_id)
+            concept_name = node['properties']['concept_name']
+            concepts.append(concept_name)
+        return concepts
+
     def is_exist_is_a_relation(self, start_word, end_word, relationtype='is a'):
         start_id = self.get_id_by_concept(start_word)
         end_id = self.get_id_by_concept(end_word)
