@@ -34,65 +34,80 @@ class TestSckg(unittest.TestCase):
         assert '--help  Show this message and exit.' in help_result.output
 
     def test_get_node_info_by_id(self):
-        graph_path = PathUtil.graph_data("KG", "V1.0.1")
+        graph_path = PathUtil.graph_data("KG", "test")
         tree = PathUtil.trie("Trie", "V1.0.2")
         sckg = SoftwareKG(graph_path, tree)
-        print(sckg.get_node_info_by_id(2724))
-        print(sckg.get_node_info_by_id(2724)['properties']['concept_name'])
+        print(sckg.get_node_info_by_id(27))
 
     def test_is_exit_facet_of_relation(self):
-        graph_path = PathUtil.graph_data("KG", "V1.0.1")
+        graph_path = PathUtil.graph_data("KG", "test")
         tree = PathUtil.trie("Trie", "V1.0.2")
         sckg = SoftwareKG(graph_path, tree)
-        assert sckg.is_exit_facet_of_relation("java", "java ee") == True
+        assert sckg.is_exit_facet_of_relation("java", "java jdk") == True
 
     def test_is_exit_relation(self):
-        graph_path = PathUtil.graph_data("KG", "V1.0.1")
+        graph_path = PathUtil.graph_data("KG", "test")
         tree = PathUtil.trie("Trie", "V1.0.2")
         sckg = SoftwareKG(graph_path, tree)
-        assert sckg.is_exit_relation("java", "java ee") == True
+        assert sckg.is_exit_relation("java", "java jdk") == True
 
     def test_is_exit_concept(self):
-        graph_path = PathUtil.graph_data("KG", "V1.0.1")
+        graph_path = PathUtil.graph_data("KG", "test")
         tree = PathUtil.trie("Trie", "V1.0.2")
         sckg = SoftwareKG(graph_path, tree)
-        sckg = SoftwareKG(graph_path, tree)
-        assert sckg.is_exist_concept("try") == True
+        assert sckg.is_exist_concept("java") == True
 
     def test_get_node_by_concept(self):
-        graph_path = PathUtil.graph_data("KG", "V1.0.1")
+        graph_path = PathUtil.graph_data("KG", "test")
         tree = PathUtil.trie("Trie", "V1.0.2")
         sckg = SoftwareKG(graph_path, tree)
-        sckg = SoftwareKG(graph_path, tree)
         print(sckg.get_node_by_concept("I'm trying to"))
 
+    def test_get_in_relations(self):
+        graph_path = PathUtil.graph_data("KG", "test")
+        tree = PathUtil.trie("Trie", "V1.0.2")
+        sckg = SoftwareKG(graph_path, tree)
+        print(sckg.get_out_relations("java"))
+
+    def test_get_concept_by_id(self):
+        graph_path = PathUtil.graph_data("KG", "test")
+        tree = PathUtil.trie("Trie", "V1.0.2")
+        sckg = SoftwareKG(graph_path, tree)
+        print(sckg.get_concept_by_id(2))
+
     def test_find_common_out_relationship_node(self):
-        graph_path = PathUtil.graph_data("KG", "V1.0.1")
+        graph_path = PathUtil.graph_data("KG", "test")
         tree = PathUtil.trie("Trie", "V1.0.2")
         sckg = SoftwareKG(graph_path, tree)
         print(sckg.find_common_out_relationship_node("java jdk", "java ee"))
 
     def test_find_out_is_a_relation_concept(self):
-        graph_path = PathUtil.graph_data("KG", "V1.0.1")
+        graph_path = PathUtil.graph_data("KG", "test")
         tree = PathUtil.trie("Trie", "V1.0.2")
         sckg = SoftwareKG(graph_path, tree)
-        print(sckg.find_out_is_a_relation_concept("java jdk"))
+        print(sckg.find_out_is_a_relation_concept("java"))
 
     def test_find_common_in_relationship_node(self):
-        graph_path = PathUtil.graph_data("KG", "V1.0.1")
+        graph_path = PathUtil.graph_data("KG", "test")
         tree = PathUtil.trie("Trie", "V1.0.2")
         sckg = SoftwareKG(graph_path, tree)
-        print(sckg.find_common_in_relationship_node("java", "java ee"))
+        print(sckg.find_common_in_relationship_node("java", "java jdk"))
 
     def test_find_include_prefix_concept(self):
-        graph_path = PathUtil.graph_data("KG", "V1.0.1")
+        graph_path = PathUtil.graph_data("KG", "test")
         tree = PathUtil.trie("Trie", "V1.0.2")
         sckg = SoftwareKG(graph_path, tree)
         print(sckg.find_include_prefix_concept("java"))
 
     def test_find_all_concept_from_sentence(self):
-        graph_path = PathUtil.graph_data("KG", "V1.0.1")
+        graph_path = PathUtil.graph_data("KG", "test")
         tree = PathUtil.trie("Trie", "V1.0.2")
         sckg = SoftwareKG(graph_path, tree)
         print(sckg.find_all_concept_from_sentence("Ambiguous Controller Names in ASP.NET MVC"))
         # print(sckg.find_all_concept_from_sentence("Is it possible to use private field conventions for Fluent NHibernate Automapping?"))
+
+    def test_get_all_concept(self):
+        graph_path = PathUtil.graph_data("KG", "test")
+        tree = PathUtil.trie("Trie", "V1.0.2")
+        sckg = SoftwareKG(graph_path, tree)
+        print(sckg.get_all_concept())
